<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>DateWindow</name>
    <message>
        <location filename="DateWindow.py" line="59"/>
        <source>QNetMan (Select date)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="DialogRefreshInterval.py" line="47"/>
        <source>QNetMan (Refresh interval)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshInterval.py" line="48"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshInterval.py" line="51"/>
        <source>1 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshInterval.py" line="52"/>
        <source>2 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshInterval.py" line="53"/>
        <source>3 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshInterval.py" line="54"/>
        <source>4 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshInterval.py" line="55"/>
        <source>5 sec</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogDBStat</name>
    <message>
        <location filename="DialogDBStatistics.py" line="91"/>
        <source>QNetMan (Database statistics)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="92"/>
        <source>Database file size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="93"/>
        <source>0000 KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="94"/>
        <source>Table traffic statistics:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="97"/>
        <source>000000 records</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="96"/>
        <source>Table sessions statistics:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="98"/>
        <source>First entry:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="99"/>
        <source>Last entry:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="102"/>
        <source>YYYY-MM-DD HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogDBStatistics.py" line="100"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogMonitorOptions</name>
    <message>
        <location filename="MonitorOptions.py" line="77"/>
        <source>QNetMan (Monitor options)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MonitorOptions.py" line="78"/>
        <source>Timestamp (vertcal line), seconds:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogRecordDataExt</name>
    <message>
        <location filename="DialogRecordDataExt.py" line="91"/>
        <source>Attention! Data recording will continue to until it is stopped manually, or network interface will be deactivated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordDataExt.py" line="95"/>
        <source>Data record is disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordDataExt.py" line="112"/>
        <source>MAC address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordDataExt.py" line="113"/>
        <source>RX bytes/RX packets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordDataExt.py" line="114"/>
        <source>TX bytes/TX packets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordDataExt.py" line="116"/>
        <source>Network interface</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogRecordManager</name>
    <message>
        <location filename="DialogRecordData.py" line="51"/>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordData.py" line="53"/>
        <source>Auto
record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRecordData.py" line="50"/>
        <source>QNetMan (Data record)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogRefreshNetstat</name>
    <message>
        <location filename="DialogRefreshNetstat.py" line="31"/>
        <source>QNetMan (Refresh interval)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="34"/>
        <source>5 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="35"/>
        <source>10 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="36"/>
        <source>15 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="37"/>
        <source>20 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="38"/>
        <source>30 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="39"/>
        <source>40 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogRefreshNetstat.py" line="40"/>
        <source>60 seconds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogSessionOptions</name>
    <message>
        <location filename="ViewSessionOptions.py" line="75"/>
        <source>QNetMan (Session options)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSessionOptions.py" line="76"/>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSessionOptions.py" line="77"/>
        <source>Timestamp (vertcal line), min:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSessionOptions.py" line="78"/>
        <source>RX / TX:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListSessions</name>
    <message>
        <location filename="ListSessions.py" line="87"/>
        <source>QNetMan (Networking sessions)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="88"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="89"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="90"/>
        <source>Select all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="91"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="92"/>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="93"/>
        <source>Database statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="94"/>
        <source>Clean database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessions.py" line="95"/>
        <source>Calculate traffic</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListSessionsExt</name>
    <message>
        <location filename="ListSessionsExt.py" line="107"/>
        <source>Deleting sessions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="108"/>
        <source>Delete selected sessions ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="170"/>
        <source>Session full time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="264"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="265"/>
        <source>Session does not contain data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="323"/>
        <source>records</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="126"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="127"/>
        <source>Sorry, an error in the database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="361"/>
        <source>Select a session to calculate the traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="366"/>
        <source>Sessions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="369"/>
        <source>Full traffic:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="367"/>
        <source>RX bytes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ListSessionsExt.py" line="368"/>
        <source>TX bytes:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="MainWindow.py" line="76"/>
        <source>QNetMan (QNetworkManager)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="78"/>
        <source>Network
sessions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="81"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="83"/>
        <source>Network
connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="225"/>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="85"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="156"/>
        <source>Frequency of data collection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="157"/>
        <source>10 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="158"/>
        <source>15 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="159"/>
        <source>20 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="160"/>
        <source>30 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="161"/>
        <source>40 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="162"/>
        <source>60 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="163"/>
        <source>Database time limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="164"/>
        <source>2 weeks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="165"/>
        <source>1 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="166"/>
        <source>2 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="167"/>
        <source>3 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="168"/>
        <source>4 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="169"/>
        <source>5 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="170"/>
        <source>6 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="171"/>
        <source>9 months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="172"/>
        <source>1 year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="173"/>
        <source>not limited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="174"/>
        <source>DateTime format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="175"/>
        <source>YYYY-MM-DD HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="176"/>
        <source>MM-DD-YYYY HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="177"/>
        <source>DD-MM-YYYY HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="178"/>
        <source>DD.MM.YYYY HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="179"/>
        <source>MM.DD.YYYY HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="180"/>
        <source>YYYY.MM.DD HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="181"/>
        <source>DD/MM/YYYY HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="182"/>
        <source>MM/DD/YYYY HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="183"/>
        <source>YYYY/MM/DD HH:MM:SS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="184"/>
        <source>Graphs colors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="185"/>
        <source>RX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="186"/>
        <source>TX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="187"/>
        <source>Supported network interfaces:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="120"/>
        <source>gprs0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="121"/>
        <source>wlan0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="123"/>
        <source>usb0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="124"/>
        <source>eth0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="122"/>
        <source>pan0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="204"/>
        <source>QNetMan (Sessions)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="205"/>
        <source>Session start time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="206"/>
        <source>Session end time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="208"/>
        <source>2000-01-01 00:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="217"/>
        <source>RX:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="212"/>
        <source>0000.00 MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="218"/>
        <source>TX:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="213"/>
        <source>Session full time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="214"/>
        <source>00 h; 00 m; 00 s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="215"/>
        <source>Full session traffic :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="216"/>
        <source>000000 MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="226"/>
        <source>Remove session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="86"/>
        <source>QNetMan (About)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="87"/>
        <source>QNetworkManager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="88"/>
        <source>Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="90"/>
        <source>Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="91"/>
        <source>Kozlov Anatoliy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="92"/>
        <source>&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="93"/>
        <source>&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="94"/>
        <source>Homepage:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="99"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Microsoft Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qnetman.garage.maemo.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://qnetman.garage.maemo.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="115"/>
        <source>QNetMan (Session filters)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="116"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="119"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="126"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="127"/>
        <source>Session start time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WindowFilterOptions.py" line="128"/>
        <source>Session end time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindow.py" line="155"/>
        <source>QNetMan (Settings)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindow.py" line="80"/>
        <source>Monitor 
connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="223"/>
        <source>000 kB/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAbout.py" line="89"/>
        <source>0.4.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSession.py" line="224"/>
        <source>Please, wait ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowExt</name>
    <message>
        <location filename="MainWindowExt.py" line="36"/>
        <source>Daemon QNetMan is not running.
Start daemons now ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindowExt.py" line="37"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindowExt.py" line="42"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindowExt.py" line="43"/>
        <source>Please restart the program now.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindowExt.py" line="46"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindowExt.py" line="47"/>
        <source>Failed to start daemon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="MainWindowExt.py" line="50"/>
        <source>Features will be limited.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsWindowExt</name>
    <message>
        <location filename="OptionsWindowExt.py" line="298"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindowExt.py" line="283"/>
        <source>Should be left on at least one network interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OptionsWindowExt.py" line="299"/>
        <source>Before you disable the network interface, turn off the record on this network interface</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewCurrentSession</name>
    <message>
        <location filename="ViewCurrentSession.py" line="162"/>
        <source>QNetMan (Monitor)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="175"/>
        <source>RX:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="165"/>
        <source>000.00 MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="176"/>
        <source>TX:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="168"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="170"/>
        <source>000.00 MB/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="171"/>
        <source>rx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="172"/>
        <source>tx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="173"/>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="174"/>
        <source>2 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="177"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="178"/>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSession.py" line="179"/>
        <source>Network interface</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewCurrentSessionExt</name>
    <message>
        <location filename="ViewCurrentSessionExt.py" line="501"/>
        <source>Refresh interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSessionExt.py" line="502"/>
        <source>sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSessionExt.py" line="631"/>
        <source>Selected network interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewCurrentSessionExt.py" line="674"/>
        <source>Recording...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewSessionExt</name>
    <message>
        <location filename="ViewSessionExt.py" line="206"/>
        <source>h</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSessionExt.py" line="207"/>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ViewSessionExt.py" line="208"/>
        <source>s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WinAboutExt</name>
    <message>
        <location filename="WinAboutExt.py" line="132"/>
        <source>Thanks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAboutExt.py" line="145"/>
        <source>Licence:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAboutExt.py" line="146"/>
        <source>GPL v2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAboutExt.py" line="134"/>
        <source>Used icon set &quot;Crystal-clear&quot; by Everaldo Coelho</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAboutExt.py" line="123"/>
        <source>Qt-based network manager which allows to monitor your network traffic. It is possible to record network sessions information for different connections and provide the information in graphical view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinAboutExt.py" line="133"/>
        <source>Vladimir Sinichkin - for translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WinNetStat</name>
    <message>
        <location filename="WinNetStat.py" line="120"/>
        <source>QNetMan (NetStat)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="121"/>
        <source>Resolve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="123"/>
        <source>Auto
refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="124"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="125"/>
        <source>Local Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="126"/>
        <source>Foreign Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="127"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="128"/>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStat.py" line="129"/>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WinNetStatExt</name>
    <message>
        <location filename="WinNetStatExt.py" line="229"/>
        <source>Refresh interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStatExt.py" line="230"/>
        <source>sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="WinNetStatExt.py" line="240"/>
        <source>Please, wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dlgNetworkSelect</name>
    <message>
        <location filename="DialogNetworkIface.py" line="54"/>
        <source>QNetMan (Select network interface)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogNetworkIface.py" line="57"/>
        <source>gprs0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogNetworkIface.py" line="58"/>
        <source>wlan0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogNetworkIface.py" line="59"/>
        <source>lo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogNetworkIface.py" line="61"/>
        <source>iface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogNetworkIface.py" line="62"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="DialogNetworkIface.py" line="64"/>
        <source>Select the network interface
 for monitoring</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
